@@ -1,5 +1,5 @@
 #' @importFrom rlang .data
-get_stats <- function(self, type, entity, leagues, ...) {
+.get_stats <- function(self, type, entity, leagues, ...) {
     query <- list(...)
     if (!all(rlang::have_name(query))) {
         bad <- which(!rlang::have_name(query)) + 1
@@ -7,6 +7,8 @@ get_stats <- function(self, type, entity, leagues, ...) {
         stop(msg)
     }
 
+    .check_clear_cache(self)
+
     if (type == "salaries") {
         .check_leagues_salaries(self, leagues)
         if (missing(leagues)) leagues <- "mls"
