@@ -18,13 +18,13 @@ test_that("Querying player-level xPass values works properly", {
     LEAGUES <- "mls"
 
     .exp <- asa_client$players %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$player_id) %>%
-        dplyr::pull(.data$player_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(player_id) %>%
+        dplyr::pull(player_id)
 
     .obj <- asa_client$get_player_xpass(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$player_id %in% .exp) %>%
+        dplyr::mutate(obj = player_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -34,13 +34,13 @@ test_that("Querying player-level xPass values works properly", {
     LEAGUES <- c("mls", "uslc")
 
     .exp <- asa_client$players %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$player_id) %>%
-        dplyr::pull(.data$player_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(player_id) %>%
+        dplyr::pull(player_id)
 
     .obj <- asa_client$get_player_xpass(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$player_id %in% .exp) %>%
+        dplyr::mutate(obj = player_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -49,7 +49,7 @@ test_that("Querying player-level xPass values works properly", {
     # Minimum minutes ----------------------------------------------------
     .exp <- 1000
     .obj <- asa_client$get_player_xpass(minimum_minutes = .exp) %>%
-        dplyr::pull(.data$minutes_played) %>%
+        dplyr::pull(minutes_played) %>%
         min()
 
     expect_gte(.obj, .exp)
@@ -57,7 +57,7 @@ test_that("Querying player-level xPass values works properly", {
     # Minimum passes -----------------------------------------------------
     .exp <- 1000
     .obj <- asa_client$get_player_xpass(minimum_passes = .exp) %>%
-        dplyr::pull(.data$attempted_passes) %>%
+        dplyr::pull(attempted_passes) %>%
         min()
 
     expect_gte(.obj, .exp)
@@ -69,11 +69,11 @@ test_that("Querying player-level xPass values works properly", {
     IDS <- "vzqo8xZQap"
 
     .obj <- asa_client$get_player_xpass(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -82,11 +82,11 @@ test_that("Querying player-level xPass values works properly", {
     IDS <- c("vzqo8xZQap", "9vQ22BR7QK")
 
     .obj <- asa_client$get_player_xpass(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -95,11 +95,11 @@ test_that("Querying player-level xPass values works properly", {
     NAMES <- "Dax McCarty"
 
     .obj <- asa_client$get_player_xpass(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -108,11 +108,11 @@ test_that("Querying player-level xPass values works properly", {
     NAMES <- c("Dax McCarty", "Tiffany McCarty")
 
     .obj <- asa_client$get_player_xpass(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -124,12 +124,12 @@ test_that("Querying player-level xPass values works properly", {
     IDS <- "NWMWlBK5lz"
 
     .obj <- asa_client$get_player_xpass(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
-        dplyr::distinct(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
+        dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -138,12 +138,12 @@ test_that("Querying player-level xPass values works properly", {
     IDS <- c("a2lqRX2Mr0", "9Yqdwg85vJ")
 
     .obj <- asa_client$get_player_xpass(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -152,12 +152,12 @@ test_that("Querying player-level xPass values works properly", {
     NAMES <- "Red Bulls"
 
     .obj <- asa_client$get_player_xpass(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -166,12 +166,12 @@ test_that("Querying player-level xPass values works properly", {
     NAMES <- c("Chicago", "Seattle")
 
     .obj <- asa_client$get_player_xpass(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -197,18 +197,18 @@ test_that("Querying player-level xPass values works properly", {
     # Single position ----------------------------------------------------
     .exp <- "AM"
     .obj <- asa_client$get_player_xpass(general_position = .exp) %>%
-        dplyr::distinct(.data$general_position) %>%
-        dplyr::arrange(.data$general_position) %>%
-        dplyr::pull(.data$general_position)
+        dplyr::distinct(general_position) %>%
+        dplyr::arrange(general_position) %>%
+        dplyr::pull(general_position)
 
     expect_equal(.obj, .exp)
 
     # Multiple positions -------------------------------------------------
     .exp <- c("AM", "DM")
     .obj <- asa_client$get_player_xpass(general_position = .exp) %>%
-        dplyr::distinct(.data$general_position) %>%
-        dplyr::arrange(.data$general_position) %>%
-        dplyr::pull(.data$general_position)
+        dplyr::distinct(general_position) %>%
+        dplyr::arrange(general_position) %>%
+        dplyr::pull(general_position)
 
     expect_equal(.obj, .exp)
 
@@ -234,13 +234,13 @@ test_that("Querying team-level xPass values works properly", {
     LEAGUES <- "mls"
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$team_id) %>%
-        dplyr::pull(.data$team_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(team_id) %>%
+        dplyr::pull(team_id)
 
     .obj <- asa_client$get_team_xpass(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$team_id %in% .exp) %>%
+        dplyr::mutate(obj = team_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -250,13 +250,13 @@ test_that("Querying team-level xPass values works properly", {
     LEAGUES <- c("mls", "uslc")
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$team_id) %>%
-        dplyr::pull(.data$team_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(team_id) %>%
+        dplyr::pull(team_id)
 
     .obj <- asa_client$get_team_xpass(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$team_id %in% .exp) %>%
+        dplyr::mutate(obj = team_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -269,12 +269,12 @@ test_that("Querying team-level xPass values works properly", {
     IDS <- "NWMWlBK5lz"
 
     .obj <- asa_client$get_team_xpass(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
-        dplyr::distinct(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
+        dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -283,12 +283,12 @@ test_that("Querying team-level xPass values works properly", {
     IDS <- c("a2lqRX2Mr0", "9Yqdwg85vJ")
 
     .obj <- asa_client$get_team_xpass(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -297,12 +297,12 @@ test_that("Querying team-level xPass values works properly", {
     NAMES <- "Red Bulls"
 
     .obj <- asa_client$get_team_xpass(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -311,12 +311,12 @@ test_that("Querying team-level xPass values works properly", {
     NAMES <- c("Chicago", "Seattle")
 
     .obj <- asa_client$get_team_xpass(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
